@@ -15,26 +15,20 @@ use Exporter;
 use HTTP::Date qw/parse_date str2time/;
 use Time::Moment;
 
-our $VERSION        = '3.4';
-
-# Date handling
-our $DateParsing       = 1;
-our $DateTimeCreate    = 1;
-our $EpochCreate       = 0;
-
-our $NormalizeToUTC    = 0;
-our $IgnoreTimeZones   = 0;
+our $VERSION = '3.5';
 
+# Default for Handling Parsing
+our $DateParsing     = 1;
+our $DateTimeCreate  = 1;
+our $EpochCreate     = 1;
+our $NormalizeToUTC  = 0;
+our $IgnoreTimeZones = 0;
+our $ExtractProgram  = 1;
+our $PruneRaw        = 0;
+our $PruneEmpty      = 0;
+our @PruneFields     = ();
 our $FmtDate;
 
-our $ExtractProgram    = 1;
-
-our $PruneRaw          = 0;
-our $PruneEmpty        = 0;
-our @PruneFields       = ();
-
-our $RegexSet          = 'stable';
-
 
 my %INT_PRIORITY = (
     'emerg'         => 0,
@@ -112,71 +106,37 @@ our %EXPORT_TAGS = (
     with_timezones  => [ qw(parse_syslog_line set_syslog_timezone get_syslog_timezone use_utc_syslog) ],
 );
 
-# Regex to Support Matches
- my %RE = (
-    IPv4    => qr/(?:[0-9]{1,3}\.){3}[0-9]{1,3}/,
-);
-
 # Regex to Extract Data
-my %REGEXP = (
-    stable => {
-        preamble        => qr/^\<(\d+)\>/,
-        date            => qr/^(?:\d{4} )?([a-zA-Z]{3}\s+[0-9]+\s+[0-9]{1,2}(?:\:[0-9]{2}){1,2})/,
-        date_long => qr/^
-                (?:[0-9]{4}\s+)?                # Year: Because, Cisco
-                ([.*])?                         # Cisco adds a * for no ntp, and a . for configured but out of sync
-                [a-zA-Z]{3}\s+[0-9]+            # Date: Jan  1
-                (?:\s+[0-9]{4})?                # Year: Because, Cisco
-                \s+                             # Date Separator: spaces
-                [0-9]{1,2}(?:\:[0-9]{2}){1,2}   # Time: HH:MM or HH:MM:SS
-                (?:\.[0-9]{3,6})?               # Time: .DDD(DDD) ms resolution
-                (?:\s+[A-Z]{3,4})?              # Timezone, ZZZ or ZZZZ
-                (?:\:?)                         # Cisco adds a : after the second timestamp
-        /x,
-        date_iso8601    => qr/^(
-                [0-9]{4}(\-[0-9]{2}){2}         # Date YYYY-MM-DD
-                (\s|T)                          # Date Separator T or ' '
-                [0-9]{2}(\:[0-9]{2}){1,2}       # Time HH:MM:SS
-                (?:\.(?:[0-9]{3}){1,2})?        # Time: .DDD millisecond or .DDDDDD microsecond resolution
-                ([Zz]|[+\-][0-9]{2}\:[0-9]{2})  # UTC Offset +DD:MM or 'Z' indicating UTC-0
-        )/x,
-        host            => qr/^\s*([^:\s]+)\s+/,
-        cisco_hates_you => qr/^\s*[0-9]*:\s+/,
-        program_raw     => qr/^\s*([^\[][^:]+):\s*/,
-        program_name    => qr/^([^\[\(\ ]+)/,
-        program_sub     => qr/\(([^\)]+)\)/,
-        program_pid     => qr/\[([^\]]+)\]/,
-        program_netapp  => qr/\[([^\]]+)\]:\s*/,
-    },
-    devel => {
-        preamble        => qr/^\<(\d+)\>/,
-        date            => qr/^(?:\d{4} )?([a-zA-Z]{3}\s+[0-9]+\s+[0-9]{1,2}(?:\:[0-9]{2}){1,2})/,
-        date_long => qr/^
-                (?:[0-9]{4}\s+)?                # Year: Because, Cisco
-                ([.*])?                         # Cisco adds a * for no ntp, and a . for configured but out of sync
-                [a-zA-Z]{3}\s+[0-9]+            # Date: Jan  1
-                (?:\s+[0-9]{4})?                # Year: Because, Cisco
-                \s+                             # Date Separator: spaces
-                [0-9]{1,2}(?:\:[0-9]{2}){1,2}   # Time: HH:MM or HH:MM:SS
-                (?:\.[0-9]{3,6})?               # Time: .DDD(DDD) ms resolution
-                (?:\s+[A-Z]{3,4})?              # Timezone, ZZZ or ZZZZ
-                (?:\:?)                         # Cisco adds a : after the second timestamp
-        /x,
-        date_iso8601    => qr/^(
-                [0-9]{4}(?:\-[0-9]{2}){2}     # Date YYYY-MM-DD
-                (?:\s|T)                      # Date Separator T or ' '
-                [0-9]{2}(\:[0-9]{2}){1,2}   # Time HH:MM:SS
-                (?:\.(?:[0-9]{3}){1,2})?    # Time: .DDD millisecond or .DDDDDD microsecond resolution
-                ([Zz]|[+\-][0-9]{2}\:[0-9]{2})  # UTC Offset +DD:MM or 'Z' indicating UTC-0
-        )/x,
-        host            => qr/^\s*([^:\s]+)\s+/,
-        cisco_hates_you => qr/^\s*[0-9]*:\s+/,
-        program_raw     => qr/^\s*([^\[][^:]+):\s*/,
-        program_name    => qr/^([^\[\(\ ]+)/,
-        program_sub     => qr/\(([^\)]+)\)/,
-        program_pid     => qr/\[([^\]]+)\]/,
-        program_netapp  => qr/\[([^\]]+)\]:\s*/,
-    },
+const my %RE => (
+    IPv4            => qr/(?:[0-9]{1,3}\.){3}[0-9]{1,3}/,
+    preamble        => qr/^\<(\d+)\>/,
+    year            => qr/^(\d{4}) /,
+    date            => qr/^([a-zA-Z]{3}\s+[0-9]+\s+[0-9]{1,2}(?:\:[0-9]{2}){1,2})/,
+    date_long => qr/^
+            (?:[0-9]{4}\s+)?                # Year: Because, Cisco
+            ([.*])?                         # Cisco adds a * for no ntp, and a . for configured but out of sync
+            [a-zA-Z]{3}\s+[0-9]+            # Date: Jan  1
+            (?:\s+[0-9]{4})?                # Year: Because, Cisco
+            \s+                             # Date Separator: spaces
+            [0-9]{1,2}(?:\:[0-9]{2}){1,2}   # Time: HH:MM or HH:MM:SS
+            (?:\.[0-9]{3,6})?               # Time: .DDD(DDD) ms resolution
+            (?:\s+[A-Z]{3,4})?              # Timezone, ZZZ or ZZZZ
+            (?:\:?)                         # Cisco adds a : after the second timestamp
+    /x,
+    date_iso8601    => qr/^(
+            [0-9]{4}(\-[0-9]{2}){2}         # Date YYYY-MM-DD
+            (\s|T)                          # Date Separator T or ' '
+            [0-9]{2}(\:[0-9]{2}){1,2}       # Time HH:MM:SS
+            (?:\.(?:[0-9]{3}){1,2})?        # Time: .DDD millisecond or .DDDDDD microsecond resolution
+            ([Zz]|[+\-][0-9]{2}\:[0-9]{2})  # UTC Offset +DD:MM or 'Z' indicating UTC-0
+    )/x,
+    host            => qr/^\s*([^:\s]+)\s+/,
+    cisco_hates_you => qr/^\s*[0-9]*:\s+/,
+    program_raw     => qr/^\s*([^\[][^:]+):\s*/,
+    program_name    => qr/^([^\[\(\ ]+)/,
+    program_sub     => qr/\(([^\)]+)\)/,
+    program_pid     => qr/\[([^\]]+)\]/,
+    program_netapp  => qr/\[([^\]]+)\]:\s*/,
 );
 
 
@@ -195,16 +155,13 @@ my $SYSLOG_TIMEZONE = 'local';
 sub parse_syslog_line {
     my ($raw_string) = @_;
 
-    # Verify we have a valid RegexSet
-    die "Invalid RegexSet '$RegexSet', valid are: ". join(", ", sort keys %REGEXP) unless exists $REGEXP{$RegexSet};
-
     # Initialize everything to undef
     my %msg =  $PruneEmpty ? () : %_empty_msg;
     $msg{message_raw} = $raw_string unless $PruneRaw;
 
     #
     # grab the preamble:
-    if( $raw_string =~ s/$REGEXP{$RegexSet}->{preamble}//o ) {
+    if( $raw_string =~ s/$RE{preamble}//o ) {
         # Cast to integer
         $msg{preamble} = int $1;
 
@@ -219,10 +176,14 @@ sub parse_syslog_line {
 
     #
     # Handle Date/Time
-    if( $raw_string =~ s/$REGEXP{$RegexSet}->{date}//o) {
+    my $year;
+    if( $raw_string =~ s/$RE{year}//o ) {
+        $year = $1;
+    }
+    if( $raw_string =~ s/$RE{date}//o) {
         $msg{datetime_raw} = $1;
     }
-    elsif( $raw_string =~ s/$REGEXP{$RegexSet}->{date_iso8601}//o) {
+    elsif( $raw_string =~ s/$RE{date_iso8601}//o) {
         $msg{datetime_raw} = $1;
     }
     if( exists $msg{datetime_raw} && length $msg{datetime_raw} ) {
@@ -237,10 +198,10 @@ sub parse_syslog_line {
             elsif( $DateTimeCreate ) {
                 # We need DateTime to interpret missing timezone offsets taking DST into account
                 my $dt = DateTime::Format::HTTP->parse_datetime(
-                    $msg{datetime_raw},
-                    $NormalizeToUTC
-                        ? _get_timezone_from_cache(get_syslog_timezone())
-                        : (),
+                        $msg{datetime_raw} . (defined $year ? " $year" : ''),
+                        $NormalizeToUTC
+                            ? _get_timezone_from_cache(get_syslog_timezone())
+                            : (),
                 );
 
                 my $tm;
@@ -273,13 +234,13 @@ sub parse_syslog_line {
                 }
             }
             elsif ( $EpochCreate ) {
-                $msg{epoch}        = HTTP::Date::str2time($msg{datetime_raw});
+                $msg{epoch}        = HTTP::Date::str2time($msg{datetime_raw} . (defined $year ? " $year" : ''));
                 $msg{datetime_str} = HTTP::Date::time2iso($msg{epoch});
             }
             elsif ( $IgnoreTimeZones ) {
 
                 # qw/year month day hour minute second/;
-                my @parsed = HTTP::Date::parse_date($msg{datetime_raw});
+                my @parsed = HTTP::Date::parse_date($msg{datetime_raw} . (defined $year ? " $year" : ''));
 
                 # if raw string contained timezone, ignore it explicitly
                 $msg{date}          = sprintf("%d-%02d-%02d", @parsed[0..2]);
@@ -293,6 +254,7 @@ sub parse_syslog_line {
                     $tm = Time::Moment->from_string($msg{datetime_raw}, lenient => 1);
                 };
                 if (not $EVAL_ERROR) {
+                    $tm->year($year) if defined $year;
 
                     $msg{date}         = $tm->strftime("%F");
                     $msg{'time'}       = $tm->strftime("%T%f");
@@ -312,7 +274,7 @@ sub parse_syslog_line {
 
     #
     # Host Information:
-    if( $raw_string =~ s/$REGEXP{$RegexSet}->{host}//o ) {
+    if( $raw_string =~ s/$RE{host}//o ) {
         my $hostStr = $1;
         my($ip) = ($hostStr =~ /($RE{IPv4})/o);
         if( defined $ip && length $ip ) {
@@ -326,9 +288,9 @@ sub parse_syslog_line {
             $msg{domain} = $domain;
         }
     }
-    if( $raw_string =~ s/$REGEXP{$RegexSet}->{cisco_hates_you}//o ) {
+    if( $raw_string =~ s/$RE{cisco_hates_you}//o ) {
         # Yes, Cisco adds a second timestamp to it's messages, because it hates you.
-        if( $raw_string =~ s/$REGEXP{$RegexSet}->{date_long}//o ) {
+        if( $raw_string =~ s/$RE{date_long}//o ) {
             # Cisco encodes the status of NTP in the second datestamp, so let's pass it back
             if ( my $ntp = $1 ) {
                 $msg{ntp} = $ntp eq '.' ? 'out of sync'
@@ -344,19 +306,19 @@ sub parse_syslog_line {
     #
     # Parse the Program portion
     if( $ExtractProgram ) {
-        if( $raw_string =~ s/$REGEXP{$RegexSet}->{program_raw}//o ) {
+        if( $raw_string =~ s/$RE{program_raw}//o ) {
             $msg{program_raw} = $1;
             my $progStr = join ' ', grep {!exists $INT_PRIORITY{$_}} split /\s+/, $msg{program_raw};
             if( defined $progStr && length $progStr) {
-                if( ($msg{program_name}) = ($progStr =~ /$REGEXP{$RegexSet}->{program_name}/o) ) {
+                if( ($msg{program_name}) = ($progStr =~ /$RE{program_name}/o) ) {
                     if (length $msg{program_name} != length $msg{program_raw} ) {
-                        (($msg{program_pid}) = ($progStr =~ /$REGEXP{$RegexSet}->{program_pid}/o))
-                            || (($msg{program_sub}) = ($progStr =~ /$REGEXP{$RegexSet}->{program_sub}/o))
+                        (($msg{program_pid}) = ($progStr =~ /$RE{program_pid}/o))
+                            || (($msg{program_sub}) = ($progStr =~ /$RE{program_sub}/o))
                     }
                 }
             }
         }
-        elsif( $raw_string =~ s/$REGEXP{$RegexSet}->{program_netapp}//o ) {
+        elsif( $raw_string =~ s/$RE{program_netapp}//o ) {
             # Check for a [host thing.subthing:level]: tag
             #          or [host:thing.subthing:level]: tag, Thanks NetApp.
             my $subStr = $1;
@@ -489,7 +451,7 @@ Parse::Syslog::Line - Simple syslog line parser
 
 =head1 VERSION
 
-version 3.4
+version 3.5
 
 =head1 SYNOPSIS
 
@@ -577,10 +539,11 @@ Usage:
 
 =head2 DateTimeCreate
 
-If this variable is set to 1 (the default), a DateTime object will be
-returned in the $m->{datetime_obj} field.  Otherwise, this will be skipped.
-NOTE: DateTime timezone calculation is fairly slow. Unless you really need
-to take timezones into account, you're better off using other modes (below).
+If this variable is set to 1 (the default), a DateTime object will be returned in the
+$m->{datetime_obj} field.  Otherwise, this will be skipped.
+
+NOTE: DateTime timezone calculation is fairly slow. Unless you really need to
+take timezones into account, you're better off using other modes (below).
 
 Usage:
 
@@ -667,15 +630,6 @@ Usage:
 
   @Parse::Syslog::Line::PruneFields = qw(date_raw facility_int priority_int);
 
-=head2 RegexSet
-
-Allows the use of different regex sets, the default is stable.  This is mostly a developer level
-feature to allow easy benchmarking of features against previous release.
-
-Usage:
-
-  $Parse::Syslog::Line::RegexSet = 'devel';
-
 =head1 FUNCTIONS
 
 =head2 parse_syslog_line
